set_directory_properties
------------------------

Set properties of the current directory and subdirectories in key-value pairs.

::

  set_directory_properties(PROPERTIES prop1 value1 prop2 value2)

See :ref:`Directory Properties` for the list of properties known to CMake
and their individual documentation for the behavior of each property.
